<?php

namespace PortalPeople\indicator\models;

class Cart extends \backend\models\Cartsbe
{
    public function rules(): array
    {
        $rules = parent::rules();
        $rules[] = [['sourceurl'], 'default', 'value' => 'indicator'];
        $rules[] = [['status'], 'default', 'value' => 'Paid'];
        $rules[] = [['data'], 'safe'];

        return $rules;
    }
}
