<?php

return [
    'modules' => [
        'indicator' => [
            'class' => 'PortalPeople\\indicator\\Module',
            'enabled' => false,
            'protocol' => 'sftp',
            'host' => '',
            'port' => 22,
            'username' => '',
            'password' => '',
            'remotePath' => '/',
            'deleteAfterDownload' => false,
            'passiveMode' => true,
            'pickupIntervalSeconds' => 900,
            'processIntervalSeconds' => 120,
            'summaryEmail' => '',
            'defaultAccountCode' => 'ZUPA001',
            'queueComponent' => 'queue',
            'debug' => false,
        ],
    ],
];
